from django.contrib import admin
from tinymce.widgets import TinyMCE
from django.core.urlresolvers import reverse

from news.models import NewsItem

class NewsItemAdmin(admin.ModelAdmin):
	prepopulated_fields = {'slug':('title',)}
	list_display = ['title', 'date', 'site']
	list_filter = ['date']
	search_fields = ['title', 'body']
	date_hierarchy = 'date'
	ordering = ['-date']
	fieldsets = (
		('Article info', {
			'fields': ('title', 'body', 'date')
		}),
		('Image', {
			'fields': ('picture', 'caption')
		}),
		('Advanced', {
			'classes': ['collapse'],
			'fields': ('snippet', 'slug',)
		}),
	)

        def formfield_for_dbfield(self, db_field, **kwargs):
                if db_field.name in ('body', 'snippet'):
                        return db_field.formfield(widget=TinyMCE(
                                        attrs={'cols': 80, 'rows': 10},
                                        #mce_attrs={'external_link_list_url': reverse('tinymce.views.flatpages_link_list')},
                                        ))
                return super(NewsItemAdmin, self).formfield_for_dbfield(db_field, **kwargs)
        
	
	def queryset(self, request):
		return NewsItem.on_site.all()

admin.site.register(NewsItem, NewsItemAdmin)
